@@ -176,7 +176,8 @@ class FibreChannelConnector(base.BaseLinuxConnector):
 
         volume_paths = self.get_volume_paths(connection_properties)
         if volume_paths:
-            return self._linuxscsi.extend_volume(volume_paths)
+            return self._linuxscsi.extend_volume(
+                volume_paths, use_multipath=self.use_multipath)
         else:
             LOG.warning("Couldn't find any volume paths on the host to "
                         "extend volume for %(props)s",
@@ -332,8 +333,7 @@ class FibreChannelConnector(base.BaseLinuxConnector):
         mpath_path = None
         for path in volume_paths:
             real_path = self._linuxscsi.get_name_from_path(path)
-            if (self.use_multipath and not mpath_path and
-                    self.check_valid_device(path)):
+            if self.use_multipath and not mpath_path:
                 wwn = self._linuxscsi.get_scsi_wwn(path)
                 mpath_path = self._linuxscsi.find_multipath_device_path(wwn)
                 if mpath_path:
