@@ -474,7 +474,8 @@ class ISCSIConnector(base.BaseLinuxConnector, base_iscsi.BaseISCSIConnector):
         volume_paths = self.get_volume_paths(connection_properties)
         LOG.info("Found paths for volume %s", volume_paths)
         if volume_paths:
-            return self._linuxscsi.extend_volume(volume_paths)
+            return self._linuxscsi.extend_volume(
+                volume_paths, use_multipath=self.use_multipath)
         else:
             LOG.warning("Couldn't find any volume paths on the host to "
                         "extend volume for %(props)s",
